@@ -166,7 +166,7 @@ def get_icon_themes(context):
     if icon_themes_env:
         result.extend([x for x in icon_themes_env.split(':') if x])
 
-    icon_themes_cfg = context.cfg.get_all('cola.icontheme')
+    icon_themes_cfg = list(reversed(context.cfg.get_all('cola.icontheme')))
     if icon_themes_cfg:
         result.extend(icon_themes_cfg)
 
@@ -493,8 +493,11 @@ def new_worktree(context, repo, prompt):
 
         valid = model.set_worktree(gitdir)
         if not valid:
+            err = model.error
             standard.critical(
-                N_('Error Opening Repository'), N_('Could not open %s.' % gitdir)
+                N_('Error Opening Repository'),
+                message=N_('Could not open %s.' % gitdir),
+                details=err,
             )
 
 
@@ -538,6 +541,12 @@ def startup_message():
 
 def initialize():
     """System-level initialization"""
+    # We support ~/.config/git-cola/git-bindir on Windows for configuring
+    # a custom location for finding the "git" executable.
+    git_path = find_git()
+    if git_path:
+        prepend_path(git_path)
+
     # The current directory may have been deleted while we are still
     # in that directory.  We rectify this situation by walking up the
     # directory tree and retrying.
@@ -618,14 +627,6 @@ class ApplicationContext(object):
         self.runtask = qtutils.RunTask(parent=view)
 
 
-def winmain(main_fn, *argv):
-    """Find Git and launch main(argv)"""
-    git_path = find_git()
-    if git_path:
-        prepend_path(git_path)
-    return main_fn(*argv)
-
-
 def find_git():
     """Return the path of git.exe, or None if we can't find it."""
     if not utils.is_win32():
