@@ -10,7 +10,7 @@ from qtpy import QtNetwork
 from . import compat
 from . import core
 from . import icons
-from .compat import bstr
+from . import qtutils
 from .compat import parse
 from .models import prefs
 from .widgets import defs
@@ -111,15 +111,17 @@ class GravatarLabel(QtWidgets.QLabel):
     def network_finished(self, reply):
         email = self.email
 
-        header = QtCore.QByteArray(bstr('Location'))
+        header = QtCore.QByteArray(b'Location')
         location = core.decode(bytes(reply.rawHeader(header))).strip()
         if location:
             request_location = Gravatar.url_for_email(self.email, self.imgsize)
             relocated = location != request_location
         else:
             relocated = False
-
-        if reply.error() == QtNetwork.QNetworkReply.NoError:
+        no_error = qtutils.enum_value(
+            QtNetwork.QNetworkReply.NetworkError.NoError  # pylint: disable=no-member
+        )
+        if reply.error() == no_error:
             if relocated:
                 # We could do get_url(parse.unquote(location)) to
                 # download the default image.
