@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from qtpy import QtCore
 from qtpy import QtWidgets
@@ -9,7 +9,6 @@ from . import standard
 
 # pylint: disable=too-many-ancestors
 class FileTree(standard.TreeWidget):
-
     def __init__(self, parent=None):
         standard.TreeWidget.__init__(self, parent=parent)
         self.setSelectionMode(self.ExtendedSelection)
